@@ -33,6 +33,26 @@
 #define matroska_done()
 #endif
 
+#if defined(SYS_WINDOWS)
+typedef UINT (WINAPI *p_get_error_mode)(void);
+static void
+fix_windows_errormode() {
+  UINT mode      = SEM_FAILCRITICALERRORS | SEM_NOGPFAULTERRORBOX;
+  HMODULE h_kern = ::LoadLibrary("kernel32");
+
+  if (h_kern) {
+    // Vista+ only, but one can do without
+    p_get_error_mode get_error_mode = reinterpret_cast<p_get_error_mode>(::GetProcAddress(h_kern, "GetErrorMode"));
+    if (get_error_mode)
+      mode |= get_error_mode();
+
+    ::FreeLibrary(h_kern);
+  }
+
+  ::SetErrorMode(mode);
+}
+#endif
+
 // Global and static variables
 
 unsigned int verbose = 1;
@@ -98,6 +118,10 @@ mtx_common_cleanup() {
 
 void
 mtx_common_init() {
+#if defined(SYS_WINDOWS)
+  fix_windows_errormode();
+#endif
+
   matroska_init();
 
   atexit(mtx_common_cleanup);
