@@ -16,8 +16,8 @@
 
 #undef min
 #undef max
+#undef __STRICT_ANSI__
 
-#include <boost/foreach.hpp>
 #include <boost/format.hpp>
 #include <boost/regex.hpp>
 #include <string>
@@ -36,10 +36,12 @@
 # include <libintl.h>
 # if !defined Y
 #  define Y(s) gettext(s)
+#  define NY(s_singular, s_plural, count) ngettext(s_singular, s_plural, count)
 # endif
 #else /* HAVE_LIBINTL_H */
 # if !defined Y
 #  define Y(s) (s)
+#  define NY(s_singular, s_plural, count) (s_singular)
 # endif
 #endif
 
@@ -76,18 +78,16 @@ using namespace libebml;
 
 #define TIMECODE_SCALE 1000000
 
-void MTX_DLL_API mxexit(int code = -1);
-void MTX_DLL_API set_process_priority(int priority);
+void mxexit(int code = -1);
+void set_process_priority(int priority);
 
-extern unsigned int MTX_DLL_API verbose;
+extern unsigned int verbose;
 
-#define foreach                  BOOST_FOREACH
-#define reverse_foreach          BOOST_REVERSE_FOREACH
 #define mxforeach(it, vec)       for (it = (vec).begin(); it != (vec).end(); it++)
 #define mxfind(value, cont)      std::find(cont.begin(), cont.end(), value)
 #define mxfind2(it, value, cont) ((it = std::find((cont).begin(), (cont).end(), value)) != (cont).end())
 #define map_has_key(m, k)        ((m).end() != (m).find(k))
 
-void MTX_DLL_API mtx_common_init();
+void mtx_common_init();
 
 #endif // __MTX_COMMON_COMMON_H
