@@ -29,6 +29,9 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
+#include <boost/filesystem.hpp>
+#include <boost/system/error_code.hpp>
+
 #include "common/endian.h"
 #include "common/error.h"
 #include "common/fs_sys_helpers.h"
@@ -43,9 +46,9 @@ get_errno_msg() {
 }
 
 # if HAVE_POSIX_FADVISE
-static const unsigned long read_using_willneed   = 16 * 1024 * 1024;
-static const unsigned long write_before_dontneed = 8 * 1024 * 1024;
-bool mm_file_io_c::use_posix_fadvise             = false;
+static const unsigned long s_read_using_willneed   = 16 * 1024 * 1024;
+static const unsigned long s_write_before_dontneed =  8 * 1024 * 1024;
+bool mm_file_io_c::ms_use_posix_fadvise            = false;
 
 bool
 operator <(const file_id_t &file_id_1,
@@ -69,18 +72,18 @@ static std::map<file_id_t, mm_file_io_c *> s_fadvised_file_object_by_id;
   "Data integrity is not in danger."
 
 mm_file_io_c::mm_file_io_c(const std::string &path,
-                           const open_mode mode):
-  file_name(path) {
-
-  std::string local_path;
+                           const open_mode mode)
+  : m_file_name(path)
+  , m_file(NULL)
+#if HAVE_POSIX_FADVISE
+  , m_read_count(0)
+  , m_write_count(0)
+  , m_use_posix_fadvise_here(ms_use_posix_fadvise)
+#endif
+{
   const char *cmode;
 # if HAVE_POSIX_FADVISE
-  int advise;
-
-  advise = 0;
-  read_count = 0;
-  write_count = 0;
-  use_posix_fadvise_here = use_posix_fadvise;
+  int advise = 0;
 # endif
 
   switch (mode) {
@@ -109,21 +112,21 @@ mm_file_io_c::mm_file_io_c(const std::string &path,
 # endif
       break;
     default:
-      throw mm_io_error_c(Y("Unknown open mode"));
+      throw mtx::invalid_parameter_x();
   }
 
   if ((MODE_WRITE == mode) || (MODE_CREATE == mode))
     prepare_path(path);
-  local_path = g_cc_local_utf8->native(path);
+  std::string local_path = g_cc_local_utf8->native(path);
 
   struct stat st;
   if ((0 == stat(local_path.c_str(), &st)) && S_ISDIR(st.st_mode))
-    throw mm_io_open_error_c();
+    throw mtx::mm_io::open_x();
 
-  file = (FILE *)fopen(local_path.c_str(), cmode);
+  m_file = (FILE *)fopen(local_path.c_str(), cmode);
 
-  if (file == NULL)
-    throw mm_io_open_error_c();
+  if (NULL == m_file)
+    throw mtx::mm_io::open_x();
 
 # if HAVE_POSIX_FADVISE
   if (POSIX_FADV_WILLNEED == advise)
@@ -136,7 +139,7 @@ void
 mm_file_io_c::setup_fadvise(const std::string &local_path) {
   struct stat st;
   if (0 != stat(local_path.c_str(), &st))
-    throw mm_io_open_error_c();
+    throw mtx::mm_io::open_x();
 
   m_file_id.initialize(st);
 
@@ -146,9 +149,9 @@ mm_file_io_c::setup_fadvise(const std::string &local_path) {
   s_fadvised_file_count_by_id[m_file_id]++;
 
   if (1 < s_fadvised_file_count_by_id[m_file_id]) {
-    use_posix_fadvise_here = false;
+    m_use_posix_fadvise_here = false;
     if (map_has_key(s_fadvised_file_object_by_id, m_file_id))
-      s_fadvised_file_object_by_id[m_file_id]->use_posix_fadvise_here = false;
+      s_fadvised_file_object_by_id[m_file_id]->m_use_posix_fadvise_here = false;
 
   } else
     s_fadvised_file_object_by_id[m_file_id] = this;
@@ -162,13 +165,13 @@ mm_file_io_c::setFilePointer(int64 offset,
              : mode == seek_end       ? SEEK_END
              :                          SEEK_CUR;
 
-  if (fseeko((FILE *)file, offset, whence) != 0)
-    throw mm_io_seek_error_c();
+  if (fseeko((FILE *)m_file, offset, whence) != 0)
+    throw mtx::mm_io::seek_x();
 
   if (mode == seek_beginning)
     m_current_position = offset;
   else if (mode == seek_end)
-    m_current_position = ftello((FILE *)file);
+    m_current_position = ftello((FILE *)m_file);
   else
     m_current_position += offset;
 }
@@ -176,25 +179,25 @@ mm_file_io_c::setFilePointer(int64 offset,
 size_t
 mm_file_io_c::_write(const void *buffer,
                      size_t size) {
-  size_t bwritten = fwrite(buffer, 1, size, (FILE *)file);
-  if (ferror((FILE *)file) != 0)
+  size_t bwritten = fwrite(buffer, 1, size, (FILE *)m_file);
+  if (ferror((FILE *)m_file) != 0)
     mxerror(boost::format(Y("Could not write to the output file: %1% (%2%)\n")) % errno % get_errno_msg());
 
 # if HAVE_POSIX_FADVISE
-  write_count += bwritten;
-  if (use_posix_fadvise && use_posix_fadvise_here && (write_count > write_before_dontneed)) {
-    uint64 pos  = getFilePointer();
-    write_count = 0;
+  m_write_count += bwritten;
+  if (ms_use_posix_fadvise && m_use_posix_fadvise_here && (m_write_count > s_write_before_dontneed)) {
+    uint64 pos    = getFilePointer();
+    m_write_count = 0;
 
-    if (0 != posix_fadvise(fileno((FILE *)file), 0, pos, POSIX_FADV_DONTNEED)) {
-      mxverb(2, boost::format(FADVISE_WARNING) % file_name % errno % get_errno_msg());
-      use_posix_fadvise_here = false;
+    if (0 != posix_fadvise(fileno((FILE *)m_file), 0, pos, POSIX_FADV_DONTNEED)) {
+      mxverb(2, boost::format(FADVISE_WARNING) % m_file_name % errno % get_errno_msg());
+      m_use_posix_fadvise_here = false;
     }
   }
 # endif
 
   m_current_position += bwritten;
-  cached_size         = -1;
+  m_cached_size       = -1;
 
   return bwritten;
 }
@@ -202,24 +205,24 @@ mm_file_io_c::_write(const void *buffer,
 uint32
 mm_file_io_c::_read(void *buffer,
                     size_t size) {
-  int64_t bread = fread(buffer, 1, size, (FILE *)file);
+  int64_t bread = fread(buffer, 1, size, (FILE *)m_file);
 
 # if HAVE_POSIX_FADVISE
-  if (use_posix_fadvise && use_posix_fadvise_here && (0 <= bread)) {
-    read_count += bread;
-    if (read_count > read_using_willneed) {
-      uint64 pos = getFilePointer();
-      int fd     = fileno((FILE *)file);
-      read_count = 0;
+  if (ms_use_posix_fadvise && m_use_posix_fadvise_here && (0 <= bread)) {
+    m_read_count += bread;
+    if (m_read_count > s_read_using_willneed) {
+      uint64 pos   = getFilePointer();
+      int fd       = fileno((FILE *)m_file);
+      m_read_count = 0;
 
       if (0 != posix_fadvise(fd, 0, pos, POSIX_FADV_DONTNEED)) {
-        mxverb(2, boost::format(FADVISE_WARNING) % file_name % errno % get_errno_msg());
-        use_posix_fadvise_here = false;
+        mxverb(2, boost::format(FADVISE_WARNING) % m_file_name % errno % get_errno_msg());
+        m_use_posix_fadvise_here = false;
       }
 
-      if (use_posix_fadvise_here && (0 != posix_fadvise(fd, pos, pos + read_using_willneed, POSIX_FADV_WILLNEED))) {
-        mxverb(2, boost::format(FADVISE_WARNING) % file_name % errno % get_errno_msg());
-        use_posix_fadvise_here = false;
+      if (m_use_posix_fadvise_here && (0 != posix_fadvise(fd, pos, pos + s_read_using_willneed, POSIX_FADV_WILLNEED))) {
+        mxverb(2, boost::format(FADVISE_WARNING) % m_file_name % errno % get_errno_msg());
+        m_use_posix_fadvise_here = false;
       }
     }
   }
@@ -232,9 +235,9 @@ mm_file_io_c::_read(void *buffer,
 
 void
 mm_file_io_c::close() {
-  if (NULL != file) {
-    fclose((FILE *)file);
-    file = NULL;
+  if (NULL != m_file) {
+    fclose((FILE *)m_file);
+    m_file = NULL;
 
 # if HAVE_POSIX_FADVISE
     if (m_file_id.m_initialized) {
@@ -250,13 +253,13 @@ mm_file_io_c::close() {
 
 bool
 mm_file_io_c::eof() {
-  return feof((FILE *)file) != 0;
+  return feof((FILE *)m_file) != 0;
 }
 
 int
 mm_file_io_c::truncate(int64_t pos) {
-  cached_size = -1;
-  return ftruncate(fileno((FILE *)file), pos);
+  m_cached_size = -1;
+  return ftruncate(fileno((FILE *)m_file), pos);
 }
 
 /** \brief OS and kernel dependant setup
@@ -270,13 +273,13 @@ mm_file_io_c::setup() {
 # if HAVE_POSIX_FADVISE
   struct utsname un;
 
-  use_posix_fadvise = false;
+  ms_use_posix_fadvise = false;
   if ((0 == uname(&un)) && !strcasecmp(un.sysname, "Linux")) {
     std::vector<std::string> versions = split(un.release, ".");
     int major, minor;
 
     if ((2 <= versions.size()) && parse_int(versions[0], major) && parse_int(versions[1], minor) && ((2 < major) || (6 <= minor)))
-      use_posix_fadvise = true;
+      ms_use_posix_fadvise = true;
   }
 # endif // HAVE_POSIX_FADVISE
 }
@@ -285,63 +288,10 @@ mm_file_io_c::setup() {
 
 void
 mm_file_io_c::prepare_path(const std::string &path) {
-  std::string local_path = path; // contains copy of given path
-  std::string cur_path;
-
-#if defined(SYS_WINDOWS)
-  const std::string SEPARATOR ("\\");
-  // convert separators for current OS
-  std::replace(local_path.begin(), local_path.end(), '/', '\\');
-
-  if (local_path.substr(0, 2) == "\\\\") {
-    // UNC paths -- don't try to create the host name as a directory.
-
-    // Find the host name
-    std::string::size_type position = local_path.find(SEPARATOR, 2);
-    if (std::string::npos == position)
-      return;
-
-    // Find the share name
-    position = local_path.find(SEPARATOR, position + 1);
-    if (std::string::npos == position)
-      return;
-
-    cur_path = local_path.substr(0, position);
-    local_path.erase(0, position + 1);
-
-  } else if ((local_path.size() > 1) && (local_path[1] == ':')) {
-    // Skip drive letters.
-    cur_path = local_path.substr(0, 2);
-    local_path.erase(0, 3);
-
-  }
-
-#else  // SYS_WINDOWS
-  const std::string SEPARATOR ("/");
-  // convert separators for current OS
-  std::replace(local_path.begin(), local_path.end(), '\\', '/');
-#endif // SYS_WINDOWS
-
-  if (local_path.substr(0, SEPARATOR.length()) == SEPARATOR)
-    cur_path = SEPARATOR;
-
-  std::vector<std::string> parts = split(local_path, SEPARATOR);
-
-  // The file name is the last element -- remove it.
-  parts.pop_back();
-
-  for (size_t i = 0; parts.size() > i; ++i) {
-    // Ignore empty path components.
-    if (parts[i].empty())
-      continue;
-
-    if (!cur_path.empty() && (cur_path != SEPARATOR))
-      cur_path += SEPARATOR;
-    cur_path   += parts[i];
-
-    if (!fs_entry_exists(cur_path.c_str()))
-      create_directory(cur_path.c_str());
-  }
+  boost::system::error_code error_code;
+  boost::filesystem::create_directories(boost::filesystem::path(path).parent_path(), error_code);
+  if (error_code)
+    throw mtx::mm_io::create_directory_x(path, strerror(error_code.value()), error_code.value());
 }
 
 uint64
@@ -351,7 +301,7 @@ mm_file_io_c::getFilePointer() {
 
 mm_file_io_c::~mm_file_io_c() {
   close();
-  file_name = "";
+  m_file_name = "";
 }
 
 void
@@ -362,6 +312,12 @@ mm_file_io_c::cleanup() {
 #endif
 }
 
+mm_io_cptr
+mm_file_io_c::open(const std::string &path,
+                   const open_mode mode) {
+  return mm_io_cptr(new mm_file_io_c(path, mode));
+}
+
 /*
    Abstract base class.
 */
@@ -372,7 +328,7 @@ mm_io_c::getline() {
   std::string s;
 
   if (eof())
-    throw mm_io_eof_error_c();
+    throw mtx::mm_io::end_of_file_x();
 
   while (read(&c, 1) == 1) {
     if (c == '\r')
@@ -448,19 +404,17 @@ mm_io_c::read(void *buffer,
 
 uint32_t
 mm_io_c::read(std::string &buffer,
-              size_t size) {
-  char *cbuffer = new char[size + 1];
-  int nread     = read(buffer, size);
+              size_t size,
+              size_t offset) {
+  buffer.resize(offset + size);
 
-  if (0 > nread)
-    buffer = "";
-  else {
-    cbuffer[nread] = 0;
-    buffer = cbuffer;
-  }
-  delete [] cbuffer;
+  int num_read = read(&buffer[offset], size);
+  if (0 > num_read)
+    num_read = 0;
 
-  return nread;
+  buffer.resize(offset + num_read);
+
+  return num_read;
 }
 
 unsigned char
@@ -468,7 +422,7 @@ mm_io_c::read_uint8() {
   unsigned char value;
 
   if (read(&value, 1) != 1)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return value;
 }
@@ -478,7 +432,7 @@ mm_io_c::read_uint16_le() {
   unsigned char buffer[2];
 
   if (read(buffer, 2) != 2)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint16_le(buffer);
 }
@@ -488,7 +442,7 @@ mm_io_c::read_uint24_le() {
   unsigned char buffer[3];
 
   if (read(buffer, 3) != 3)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint24_le(buffer);
 }
@@ -498,7 +452,7 @@ mm_io_c::read_uint32_le() {
   unsigned char buffer[4];
 
   if (read(buffer, 4) != 4)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint32_le(buffer);
 }
@@ -508,7 +462,7 @@ mm_io_c::read_uint64_le() {
   unsigned char buffer[8];
 
   if (read(buffer, 8) != 8)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint64_le(buffer);
 }
@@ -518,7 +472,7 @@ mm_io_c::read_uint16_be() {
   unsigned char buffer[2];
 
   if (read(buffer, 2) != 2)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint16_be(buffer);
 }
@@ -528,7 +482,7 @@ mm_io_c::read_uint24_be() {
   unsigned char buffer[3];
 
   if (read(buffer, 3) != 3)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint24_be(buffer);
 }
@@ -538,7 +492,7 @@ mm_io_c::read_uint32_be() {
   unsigned char buffer[4];
 
   if (read(buffer, 4) != 4)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint32_be(buffer);
 }
@@ -548,7 +502,7 @@ mm_io_c::read_uint64_be() {
   unsigned char buffer[8];
 
   if (read(buffer, 8) != 8)
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
   return get_uint64_be(buffer);
 }
@@ -564,7 +518,7 @@ mm_io_c::read(memory_cptr &buffer,
     buffer->resize(size + offset);
 
   if (read(buffer->get_buffer() + offset, size) != size)
-    throw mm_io_eof_error_c();
+    throw mtx::mm_io::end_of_file_x();
 
   buffer->set_size(size + offset);
 
@@ -637,7 +591,7 @@ mm_io_c::write(const memory_cptr &buffer,
   size = std::min(buffer->get_size() - offset, size);
 
   if (write(buffer->get_buffer() + offset, size) != size)
-    throw mm_io_eof_error_c();
+    throw mtx::mm_io::end_of_file_x();
   return size;
 }
 
@@ -646,12 +600,12 @@ mm_io_c::skip(int64 num_bytes) {
   uint64_t pos = getFilePointer();
   setFilePointer(pos + num_bytes);
   if ((pos + num_bytes) != getFilePointer())
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 }
 
 void
 mm_io_c::save_pos(int64_t new_pos) {
-  positions.push(getFilePointer());
+  m_positions.push(getFilePointer());
 
   if (-1 != new_pos)
     setFilePointer(new_pos);
@@ -659,11 +613,11 @@ mm_io_c::save_pos(int64_t new_pos) {
 
 bool
 mm_io_c::restore_pos() {
-  if (positions.empty())
+  if (m_positions.empty())
     return false;
 
-  setFilePointer(positions.top());
-  positions.pop();
+  setFilePointer(m_positions.top());
+  m_positions.pop();
 
   return true;
 }
@@ -706,14 +660,14 @@ mm_io_c::write_bom(const std::string &charset) {
 
 int64_t
 mm_io_c::get_size() {
-  if (-1 == cached_size) {
+  if (-1 == m_cached_size) {
     save_pos();
     setFilePointer(0, seek_end);
-    cached_size = getFilePointer();
+    m_cached_size = getFilePointer();
     restore_pos();
   }
 
-  return cached_size;
+  return m_cached_size;
 }
 
 int
@@ -733,59 +687,60 @@ mm_io_c::getch() {
 
 void
 mm_proxy_io_c::close() {
-  if ((NULL != proxy_io) && proxy_delete_io)
-    delete proxy_io;
+  if ((NULL != m_proxy_io) && m_proxy_delete_io)
+    delete m_proxy_io;
 
-  proxy_io = NULL;
+  m_proxy_io = NULL;
 }
 
 
 uint32
 mm_proxy_io_c::_read(void *buffer,
                      size_t size) {
-  return proxy_io->read(buffer, size);
+  return m_proxy_io->read(buffer, size);
 }
 
 size_t
 mm_proxy_io_c::_write(const void *buffer,
                       size_t size) {
-  return proxy_io->write(buffer, size);
+  return m_proxy_io->write(buffer, size);
 }
 
 /*
    Dummy class for output to /dev/null. Needed for two pass stuff.
 */
 
-mm_null_io_c::mm_null_io_c() {
-  pos = 0;
+mm_null_io_c::mm_null_io_c()
+  : m_pos(0)
+{
 }
 
 uint64
 mm_null_io_c::getFilePointer() {
-  return pos;
+  return m_pos;
 }
 
 void
 mm_null_io_c::setFilePointer(int64 offset,
                              seek_mode mode) {
-  pos = seek_beginning == mode ? offset
-      : seek_end       == mode ? 0
-      :                          pos + offset;
+  m_pos = seek_beginning == mode ? offset
+        : seek_end       == mode ? 0
+        :                          m_pos + offset;
 }
 
 uint32
 mm_null_io_c::_read(void *buffer,
                     size_t size) {
   memset(buffer, 0, size);
-  pos += size;
+  m_pos += size;
 
   return size;
 }
 
 size_t
-mm_null_io_c::_write(const void *buffer,
+mm_null_io_c::_write(const void *,
                      size_t size) {
-  pos += size;
+  m_pos += size;
 
   return size;
 }
@@ -797,44 +752,44 @@ mm_null_io_c::close() {
 /*
    IO callback class working on memory
 */
-mm_mem_io_c::mm_mem_io_c(unsigned char *_mem,
-                         uint64_t _mem_size,
-                         int _increase)
-  : pos(0)
-  , mem_size(_mem_size)
-  , allocated(_mem_size)
-  , increase(_increase)
-  , mem(_mem)
-  , ro_mem(NULL)
-  , read_only(false)
+mm_mem_io_c::mm_mem_io_c(unsigned char *mem,
+                         uint64_t mem_size,
+                         int increase)
+  : m_pos(0)
+  , m_mem_size(mem_size)
+  , m_allocated(mem_size)
+  , m_increase(increase)
+  , m_mem(mem)
+  , m_ro_mem(NULL)
+  , m_read_only(false)
 {
-  if (0 >= increase)
-    throw error_c(Y("wrong usage: increase < 0"));
+  if (0 >= m_increase)
+    throw mtx::invalid_parameter_x();
 
-  if ((NULL == mem) && (0 < increase)) {
+  if ((NULL == m_mem) && (0 < m_increase)) {
     if (0 == mem_size)
-      allocated = increase;
+      m_allocated = increase;
 
-    mem      = (unsigned char *)safemalloc(allocated);
-    free_mem = true;
+    m_mem      = safemalloc(m_allocated);
+    m_free_mem = true;
 
   } else
-    free_mem = false;
+    m_free_mem = false;
 }
 
-mm_mem_io_c::mm_mem_io_c(const unsigned char *_mem,
-                         uint64_t _mem_size)
-  : pos(0)
-  , mem_size(_mem_size)
-  , allocated(_mem_size)
-  , increase(0)
-  , mem(NULL)
-  , ro_mem(_mem)
-  , free_mem(false)
-  , read_only(true)
+mm_mem_io_c::mm_mem_io_c(const unsigned char *mem,
+                         uint64_t mem_size)
+  : m_pos(0)
+  , m_mem_size(mem_size)
+  , m_allocated(mem_size)
+  , m_increase(0)
+  , m_mem(NULL)
+  , m_ro_mem(mem)
+  , m_free_mem(false)
+  , m_read_only(true)
 {
-  if (NULL == ro_mem)
-    throw error_c(Y("wrong usage: read-only with NULL memory"));
+  if (NULL == m_ro_mem)
+    throw mtx::invalid_parameter_x();
 }
 
 mm_mem_io_c::~mm_mem_io_c() {
@@ -843,35 +798,35 @@ mm_mem_io_c::~mm_mem_io_c() {
 
 uint64
 mm_mem_io_c::getFilePointer() {
-  return pos;
+  return m_pos;
 }
 
 void
 mm_mem_io_c::setFilePointer(int64 offset,
                             seek_mode mode) {
-  if ((NULL == mem) && (NULL == ro_mem) && (0 == mem_size))
-    throw error_c(Y("wrong usage: read-only with NULL memory"));
+  if ((NULL == m_mem) && (NULL == m_ro_mem) && (0 == m_mem_size))
+    throw mtx::invalid_parameter_x();
 
   int64_t new_pos
     = seek_beginning == mode ? offset
-    : seek_end       == mode ? mem_size - offset
-    :                          pos      + offset;
+    : seek_end       == mode ? m_mem_size - offset
+    :                          m_pos      + offset;
 
-  if ((0 <= new_pos) && (static_cast<int64_t>(mem_size) >= new_pos))
-    pos = new_pos;
+  if ((0 <= new_pos) && (static_cast<int64_t>(m_mem_size) >= new_pos))
+    m_pos = new_pos;
   else
-    throw mm_io_seek_error_c();
+    throw mtx::mm_io::seek_x();
 }
 
 uint32
 mm_mem_io_c::_read(void *buffer,
                    size_t size) {
-  size_t rbytes = std::min(size, mem_size - pos);
-  if (read_only)
-    memcpy(buffer, &ro_mem[pos], rbytes);
+  size_t rbytes = std::min(size, m_mem_size - m_pos);
+  if (m_read_only)
+    memcpy(buffer, &m_ro_mem[m_pos], rbytes);
   else
-    memcpy(buffer, &mem[pos], rbytes);
-  pos += rbytes;
+    memcpy(buffer, &m_mem[m_pos], rbytes);
+  m_pos += rbytes;
 
   return rbytes;
 }
@@ -879,92 +834,91 @@ mm_mem_io_c::_read(void *buffer,
 size_t
 mm_mem_io_c::_write(const void *buffer,
                     size_t size) {
-  if (read_only)
-    throw error_c(Y("wrong usage: writing to read-only memory"));
+  if (m_read_only)
+    throw mtx::mm_io::wrong_read_write_access_x();
 
   int64_t wbytes;
-  if ((pos + size) >= allocated) {
-    if (increase) {
-      int64_t new_allocated  = pos + size - allocated;
-      new_allocated          = ((new_allocated / increase) + 1 ) * increase;
-      allocated             += new_allocated;
-      mem                    = (unsigned char *)saferealloc(mem, allocated);
+  if ((m_pos + size) >= m_allocated) {
+    if (m_increase) {
+      int64_t new_allocated  = m_pos + size - m_allocated;
+      new_allocated          = ((new_allocated / m_increase) + 1 ) * m_increase;
+      m_allocated           += new_allocated;
+      m_mem                  = (unsigned char *)saferealloc(m_mem, m_allocated);
       wbytes                 = size;
     } else
-      wbytes = allocated - pos;
+      wbytes                 = m_allocated - m_pos;
 
   } else
     wbytes = size;
 
-  if ((pos + size) > mem_size)
-    mem_size = pos + size;
+  if ((m_pos + size) > m_mem_size)
+    m_mem_size = m_pos + size;
 
-  memcpy(&mem[pos], buffer, wbytes);
-  pos         += wbytes;
-  cached_size  = -1;
+  memcpy(&m_mem[m_pos], buffer, wbytes);
+  m_pos         += wbytes;
+  m_cached_size  = -1;
 
   return wbytes;
 }
 
 void
 mm_mem_io_c::close() {
-  if (free_mem)
-    safefree(mem);
-  mem       = NULL;
-  ro_mem    = NULL;
-  read_only = true;
-  free_mem  = false;
-  mem_size  = 0;
-  increase  = 0;
-  pos       = 0;
+  if (m_free_mem)
+    safefree(m_mem);
+  m_mem       = NULL;
+  m_ro_mem    = NULL;
+  m_read_only = true;
+  m_free_mem  = false;
+  m_mem_size  = 0;
+  m_increase  = 0;
+  m_pos       = 0;
 }
 
 bool
 mm_mem_io_c::eof() {
-  return pos >= mem_size;
+  return m_pos >= m_mem_size;
 }
 
 unsigned char *
 mm_mem_io_c::get_and_lock_buffer() {
-  free_mem = false;
-  return mem;
+  m_free_mem = false;
+  return m_mem;
 }
 
 /*
    Class for handling UTF-8/UTF-16/UTF-32 text files.
 */
 
-mm_text_io_c::mm_text_io_c(mm_io_c *_in,
-                           bool _delete_in)
-  : mm_proxy_io_c(_in, _delete_in)
-  , byte_order(BO_NONE)
-  , bom_len(0)
-  , uses_carriage_returns(false)
-  , uses_newlines(false)
-  , eol_style_detected(false)
+mm_text_io_c::mm_text_io_c(mm_io_c *in,
+                           bool delete_in)
+  : mm_proxy_io_c(in, delete_in)
+  , m_byte_order(BO_NONE)
+  , m_bom_len(0)
+  , m_uses_carriage_returns(false)
+  , m_uses_newlines(false)
+  , m_eol_style_detected(false)
 {
-  _in->setFilePointer(0, seek_beginning);
+  in->setFilePointer(0, seek_beginning);
 
   unsigned char buffer[4];
-  int num_read = _in->read(buffer, 4);
+  int num_read = in->read(buffer, 4);
   if (2 > num_read) {
-    _in->setFilePointer(0, seek_beginning);
+    in->setFilePointer(0, seek_beginning);
     return;
   }
 
-  detect_byte_order_marker(buffer, num_read, byte_order, bom_len);
+  detect_byte_order_marker(buffer, num_read, m_byte_order, m_bom_len);
 
-  _in->setFilePointer(bom_len, seek_beginning);
+  in->setFilePointer(m_bom_len, seek_beginning);
 }
 
 void
 mm_text_io_c::detect_eol_style() {
-  if (eol_style_detected)
+  if (m_eol_style_detected)
     return;
 
-
-  eol_style_detected  = true;
-  bool found_cr_or_nl = false;
+  m_eol_style_detected = true;
+  bool found_cr_or_nl  = false;
 
   save_pos();
 
@@ -975,12 +929,12 @@ mm_text_io_c::detect_eol_style() {
       break;
 
     if ((1 == len) && ('\r' == utf8char[0])) {
-      found_cr_or_nl        = true;
-      uses_carriage_returns = true;
+      found_cr_or_nl          = true;
+      m_uses_carriage_returns = true;
 
     } else if ((1 == len) && ('\n' == utf8char[0])) {
-      found_cr_or_nl = true;
-      uses_newlines  = true;
+      found_cr_or_nl  = true;
+      m_uses_newlines = true;
 
     } else if (found_cr_or_nl)
       break;
@@ -1030,13 +984,12 @@ mm_text_io_c::has_byte_order_marker(const std::string &string) {
 
 int
 mm_text_io_c::read_next_char(char *buffer) {
-  unsigned char stream[6];
-
-  if (byte_order == BO_NONE)
+  if (BO_NONE == m_byte_order)
     return read(buffer, 1);
 
+  unsigned char stream[6];
   size_t size = 0;
-  if (byte_order == BO_UTF8) {
+  if (BO_UTF8 == m_byte_order) {
     if (read(stream, 1) != 1)
       return 0;
 
@@ -1058,7 +1011,7 @@ mm_text_io_c::read_next_char(char *buffer) {
 
     return size;
 
-  } else if ((byte_order == BO_UTF16_LE) || (byte_order == BO_UTF16_BE))
+  } else if ((BO_UTF16_LE == m_byte_order) || (BO_UTF16_BE == m_byte_order))
     size = 2;
   else
     size = 4;
@@ -1068,7 +1021,7 @@ mm_text_io_c::read_next_char(char *buffer) {
 
   unsigned long data = 0;
   size_t i;
-  if ((byte_order == BO_UTF16_LE) || (byte_order == BO_UTF32_LE))
+  if ((BO_UTF16_LE == m_byte_order) || (BO_UTF32_LE == m_byte_order))
     for (i = 0; i < size; i++) {
       data <<= 8;
       data  |= stream[size - i - 1];
@@ -1105,9 +1058,9 @@ mm_text_io_c::read_next_char(char *buffer) {
 std::string
 mm_text_io_c::getline() {
   if (eof())
-    throw error_c(Y("end-of-file"));
+    throw mtx::mm_io::end_of_file_x();
 
-  if (!eol_style_detected)
+  if (!m_eol_style_detected)
     detect_eol_style();
 
   std::string s;
@@ -1122,7 +1075,7 @@ mm_text_io_c::getline() {
       return s;
 
     if ((1 == len) && (utf8char[0] == '\r')) {
-      if (previous_was_carriage_return && !uses_newlines) {
+      if (previous_was_carriage_return && !m_uses_newlines) {
         setFilePointer(-1, seek_current);
         return s;
       }
@@ -1131,7 +1084,7 @@ mm_text_io_c::getline() {
       continue;
     }
 
-    if ((1 == len) && (utf8char[0] == '\n') && (!uses_carriage_returns || previous_was_carriage_return))
+    if ((1 == len) && (utf8char[0] == '\n') && (!m_uses_carriage_returns || previous_was_carriage_return))
       return s;
 
     if (previous_was_carriage_return) {
@@ -1146,13 +1099,13 @@ mm_text_io_c::getline() {
 
 byte_order_e
 mm_text_io_c::get_byte_order() {
-  return byte_order;
+  return m_byte_order;
 }
 
 void
 mm_text_io_c::setFilePointer(int64 offset,
                              seek_mode mode) {
-  mm_proxy_io_c::setFilePointer(((0 == offset) && (seek_beginning == mode)) ? bom_len : offset, mode);
+  mm_proxy_io_c::setFilePointer(((0 == offset) && (seek_beginning == mode)) ? m_bom_len : offset, mode);
 }
 
 /*
@@ -1182,7 +1135,7 @@ mm_stdio_c::_read(void *buffer,
 size_t
 mm_stdio_c::_write(const void *buffer,
                    size_t size) {
-  cached_size = -1;
+  m_cached_size = -1;
 
   return fwrite(buffer, 1, size, stdout);
 }
