@@ -29,6 +29,7 @@
 
 #include "common/chapters/chapters.h"
 #include "common/ebml.h"
+#include "common/hacks.h"
 #include "common/kax_analyzer.h"
 #include "common/math.h"
 #include "common/matroska.h"
@@ -138,7 +139,7 @@ write_cuesheet(std::string file_name,
   if (chapters.ListSize() == 0)
     return;
 
-  if (g_no_variable_data)
+  if (hack_engaged(ENGAGE_NO_VARIABLE_DATA))
     file_name = "no-variable-data";
 
   out.write_bom("UTF-8");
@@ -208,8 +209,10 @@ extract_cuesheet(const std::string &file_name,
   }
 
   KaxChapters all_chapters;
-  KaxChapters *chapters = dynamic_cast<KaxChapters *>(analyzer->read_all(EBML_INFO(KaxChapters)));
-  KaxTags *all_tags     = dynamic_cast<KaxTags *>(analyzer->read_all(EBML_INFO(KaxTags)));
+  ebml_master_cptr chapters_m(analyzer->read_all(EBML_INFO(KaxChapters)));
+  ebml_master_cptr tags_m(    analyzer->read_all(EBML_INFO(KaxTags)));
+  KaxChapters *chapters = dynamic_cast<KaxChapters *>(chapters_m.get_object());
+  KaxTags *all_tags     = dynamic_cast<KaxTags *>(    tags_m.get_object());
 
   if ((NULL != chapters) && (NULL != all_tags)) {
     size_t i;
@@ -229,7 +232,4 @@ extract_cuesheet(const std::string &file_name,
     while (all_chapters.ListSize() > 0)
       all_chapters.Remove(0);
   }
-
-  delete all_tags;
-  delete chapters;
 }
