@@ -17,14 +17,10 @@
 #include "common/common_pch.h"
 
 #include "common/mm_io.h"
-#include "merge/pr_generic.h"
 
-class asf_reader_c: public generic_reader_c {
+class asf_reader_c {
 public:
-  static int probe_file(mm_io_c *io, uint64_t size);
-
-public:
-  asf_reader_c(track_info_c &n_ti): generic_reader_c(n_ti) { };
+  static int probe_file(mm_io_c *in, uint64_t size);
 };
 
 #endif // __R_ASF_H
