@@ -35,19 +35,19 @@ public:
     xml_parser_c(io) {
   }
 
-  virtual void start_element_cb(const char *name, const char **atts) {
+  virtual void start_element_cb(const char *name, const char **/* atts */) {
     if (m_root_element == "")
       m_root_element = name;
   }
 };
 
 int
-corepicture_reader_c::probe_file(mm_text_io_c *io,
+corepicture_reader_c::probe_file(mm_text_io_c *in,
                                  uint64_t) {
   try {
-    corepicture_xml_find_root_c root_finder(io);
+    corepicture_xml_find_root_c root_finder(in);
 
-    io->setFilePointer(0);
+    in->setFilePointer(0);
     while (root_finder.parse_one_xml_line() && (root_finder.m_root_element == ""))
       ;
 
@@ -59,34 +59,35 @@ corepicture_reader_c::probe_file(mm_text_io_c *io,
   return 0;
 }
 
-corepicture_reader_c::corepicture_reader_c(track_info_c &_ti)
-  throw (error_c):
-  generic_reader_c(_ti),
-  m_width(-1),
-  m_height(-1) {
+corepicture_reader_c::corepicture_reader_c(const track_info_c &ti,
+                                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
+  , m_width(-1)
+  , m_height(-1)
+{
+}
 
+void
+corepicture_reader_c::read_headers() {
   try {
-    m_xml_source = new mm_text_io_c(new mm_file_io_c(m_ti.m_fname));
+    m_xml_source = mm_text_io_cptr(new mm_text_io_c(m_in.get_object(), false));
 
-    if (!corepicture_reader_c::probe_file(m_xml_source, 0))
-      throw error_c(Y("corepicture_reader: Source is not a valid CorePanorama file."));
+    if (!corepicture_reader_c::probe_file(m_xml_source.get_object(), 0))
+      throw mtx::input::invalid_format_x();
 
     parse_xml_file();
 
-    delete m_xml_source;
-
     std::stable_sort(m_pictures.begin(), m_pictures.end());
     m_current_picture = m_pictures.begin();
 
-  } catch (xml_parser_error_c &error) {
-    throw error_c(error.get_error());
+  } catch (mtx::xml::parser_x &error) {
+    throw mtx::input::extended_x(error.error());
 
-  } catch (mm_io_error_c &) {
-    throw error_c(Y("corepicture_reader: Could not open the source file."));
+  } catch (mtx::mm_io::exception &) {
+    throw mtx::input::open_x();
   }
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the CorePanorama subtitle reader.\n"));
+  show_demuxer_info();
 }
 
 corepicture_reader_c::~corepicture_reader_c() {
@@ -163,7 +164,7 @@ corepicture_reader_c::start_element_cb(const char *name,
 }
 
 void
-corepicture_reader_c::end_element_cb(const char *name) {
+corepicture_reader_c::end_element_cb(const char *) {
   size_t i;
   std::string node;
 
@@ -178,38 +179,40 @@ corepicture_reader_c::end_element_cb(const char *name) {
 }
 
 void
-corepicture_reader_c::create_packetizer(int64_t tid) {
+corepicture_reader_c::create_packetizer(int64_t) {
   if (!demuxing_requested('v', 0) || (NPTZR() != 0))
     return;
 
   uint8 private_buffer[5];
   uint32 codec_used = 0;
-  std::vector<corepicture_pic_t>::const_iterator picture;
 
   private_buffer[0] = 0; // version 0
 
-  mxforeach(picture, m_pictures) {
-    if (COREPICTURE_TYPE_JPEG == picture->m_pic_type)
+  for (auto &picture : m_pictures) {
+    if (COREPICTURE_TYPE_JPEG == picture.m_pic_type)
       codec_used |= COREPICTURE_USE_JPEG;
-    else if (COREPICTURE_TYPE_PNG == picture->m_pic_type)
+    else if (COREPICTURE_TYPE_PNG == picture.m_pic_type)
       codec_used |= COREPICTURE_USE_PNG;
   }
   put_uint32_be(&private_buffer[1], codec_used);
 
-  m_ti.m_private_data = (unsigned char *)safememdup(private_buffer, sizeof(private_buffer));
+  m_ti.m_private_data = safememdup(private_buffer, sizeof(private_buffer));
   m_ti.m_private_size = sizeof(private_buffer);
   m_ptzr              = add_packetizer(new video_packetizer_c(this, m_ti, MKV_V_COREPICTURE, 0.0, m_width, m_height));
+
+  show_packetizer_info(0, PTZR(m_ptzr));
 }
 
 file_status_e
-corepicture_reader_c::read(generic_packetizer_c *ptzr,
+corepicture_reader_c::read(generic_packetizer_c *,
                            bool) {
 
   if (m_current_picture != m_pictures.end()) {
     try {
       counted_ptr<mm_io_c> io(new mm_file_io_c(m_current_picture->m_url));
-      uint64_t size  = io->get_size();
-      binary *buffer = (binary *)safemalloc(7 + size);
+      uint64_t size         = io->get_size();
+      memory_cptr mem       = memory_c::alloc(7 + size);
+      unsigned char *buffer = mem->get_buffer();
 
       put_uint16_be(&buffer[0], 7);
       put_uint32_be(&buffer[2], m_current_picture->m_pan_type);
@@ -218,8 +221,9 @@ corepicture_reader_c::read(generic_packetizer_c *ptzr,
       uint32_t bytes_read = io->read(&buffer[7], size);
 
       if (0 != bytes_read) {
+        mem->resize(7 + bytes_read);
         int64_t duration = m_current_picture->m_end_time == -1 ? -1 : m_current_picture->m_end_time - m_current_picture->m_time;
-        PTZR(m_ptzr)->process(new packet_t(new memory_c(buffer, 7 + bytes_read, false), m_current_picture->m_time, duration));
+        PTZR(m_ptzr)->process(new packet_t(mem, m_current_picture->m_time, duration));
       }
 
     } catch(...) {
@@ -235,7 +239,7 @@ int
 corepicture_reader_c::get_progress() {
   if (m_pictures.size() == 0)
     return 0;
-  return 100 - std::distance(m_current_picture, (std::vector<corepicture_pic_t>::const_iterator)m_pictures.end()) * 100 / m_pictures.size();
+  return 100 - std::distance(m_current_picture, static_cast<std::vector<corepicture_pic_t>::const_iterator>(m_pictures.end())) * 100 / m_pictures.size();
 }
 
 int64_t
@@ -243,13 +247,13 @@ corepicture_reader_c::try_to_parse_timecode(const char *s) {
   int64_t timecode;
 
   if (!parse_timecode(s, timecode))
-    throw xml_parser_error_c(Y("Invalid start timecode"), m_xml_parser);
+    throw mtx::xml::parser_x(Y("Invalid start timecode"), m_xml_parser);
 
   return timecode;
 }
 
 void
 corepicture_reader_c::identify() {
-  id_result_container("CorePanorama");
+  id_result_container();
   id_result_track(0, ID_RESULT_TRACK_VIDEO, "CorePicture");
 }
