@@ -23,6 +23,8 @@
 
 class corepicture_reader_c: public generic_reader_c, public xml_parser_c {
 private:
+  mm_text_io_cptr m_xml_source;
+
   int m_ptzr;
 
   std::vector<std::string> m_parents;
@@ -31,15 +33,20 @@ private:
   std::vector<corepicture_pic_t>::const_iterator m_current_picture;
 
 public:
-  corepicture_reader_c(track_info_c &_ti) throw (error_c);
+  corepicture_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~corepicture_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("CorePanorama pictures") : "CorePanorama pictures";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
   virtual int get_progress();
 
-  static int probe_file(mm_text_io_c *io, uint64_t size);
+  static int probe_file(mm_text_io_c *in, uint64_t size);
 
   virtual void start_element_cb(const char *name, const char **atts);
   virtual void end_element_cb(const char *name);
