@@ -16,8 +16,8 @@
 #include <ogg/ogg.h>
 #include <vorbis/codec.h>
 
+#include "common/flac.h"
 #include "common/matroska.h"
-#include "input/flac_common.h"
 #include "input/r_flac.h"
 #include "merge/output_control.h"
 #include "merge/pr_generic.h"
@@ -31,7 +31,7 @@ flac_read_cb(const FLAC__StreamDecoder *,
              FLAC__byte buffer[],
              size_t *bytes,
              void *client_data) {
-  return ((flac_reader_c *)client_data)->read_cb(buffer, bytes);
+  return reinterpret_cast<flac_reader_c *>(client_data)->read_cb(buffer, bytes);
 }
 
 static FLAC__StreamDecoderWriteStatus
@@ -39,92 +39,85 @@ flac_write_cb(const FLAC__StreamDecoder *,
               const FLAC__Frame *frame,
               const FLAC__int32 * const data[],
               void *client_data) {
-  return ((flac_reader_c *)client_data)->write_cb(frame, data);
+  return reinterpret_cast<flac_reader_c *>(client_data)->write_cb(frame, data);
 }
 
 static void
 flac_metadata_cb(const FLAC__StreamDecoder *,
                  const FLAC__StreamMetadata *metadata,
                  void *client_data) {
-  ((flac_reader_c *)client_data)->metadata_cb(metadata);
+  reinterpret_cast<flac_reader_c *>(client_data)->metadata_cb(metadata);
 }
 
 static void
 flac_error_cb(const FLAC__StreamDecoder *,
               FLAC__StreamDecoderErrorStatus status,
               void *client_data) {
-  ((flac_reader_c *)client_data)->error_cb(status);
+  reinterpret_cast<flac_reader_c *>(client_data)->error_cb(status);
 }
 
 static FLAC__StreamDecoderSeekStatus
 flac_seek_cb(const FLAC__StreamDecoder *,
              FLAC__uint64 absolute_byte_offset,
              void *client_data) {
-  return ((flac_reader_c *)client_data)->seek_cb(absolute_byte_offset);
+  return reinterpret_cast<flac_reader_c *>(client_data)->seek_cb(absolute_byte_offset);
 }
 
 static FLAC__StreamDecoderTellStatus
 flac_tell_cb(const FLAC__StreamDecoder *,
              FLAC__uint64 *absolute_byte_offset,
              void *client_data) {
-  return ((flac_reader_c *)client_data)->tell_cb(*absolute_byte_offset);
+  return reinterpret_cast<flac_reader_c *>(client_data)->tell_cb(*absolute_byte_offset);
 }
 
 static FLAC__StreamDecoderLengthStatus
 flac_length_cb(const FLAC__StreamDecoder *,
                FLAC__uint64 *stream_length,
                void *client_data) {
-  return ((flac_reader_c *)client_data)->length_cb(*stream_length);
+  return reinterpret_cast<flac_reader_c *>(client_data)->length_cb(*stream_length);
 }
 
 static FLAC__bool
 flac_eof_cb(const FLAC__StreamDecoder *,
             void *client_data) {
-  return ((flac_reader_c *)client_data)->eof_cb();
+  return reinterpret_cast<flac_reader_c *>(client_data)->eof_cb();
 }
 
-int
+bool
 flac_reader_c::probe_file(mm_io_c *io,
                           uint64_t size) {
-  unsigned char data[4];
-
   if (4 > size)
-    return 0;
+    return false;
+
+  std::string data;
   try {
     io->setFilePointer(0, seek_beginning);
     if (io->read(data, 4) != 4)
-      return 0;
+      return false;
     io->setFilePointer(0, seek_beginning);
+
+    return data == "fLaC";
   } catch (...) {
-    return 0;
+    return false;
   }
-
-  if (strncmp((char *)data, "fLaC", 4))
-    return 0;
-
-  return 1;
 }
 
-flac_reader_c::flac_reader_c(track_info_c &_ti)
-  throw (error_c):
-  generic_reader_c(_ti),
-  samples(0),
-  header(NULL) {
-
-  try {
-    file      = new mm_file_io_c(m_ti.m_fname);
-    file_size = file->get_size();
-  } catch (...) {
-    throw error_c(Y("flac_reader: Could not open the source file."));
-  }
+flac_reader_c::flac_reader_c(const track_info_c &ti,
+                             const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
+  , samples(0)
+{
+}
 
+void
+flac_reader_c::read_headers() {
   if (g_identifying)
     return;
 
-  mxinfo_fn(m_ti.m_fname, Y("Using the FLAC demultiplexer.\n"));
+  show_demuxer_info();
 
   if (!parse_file())
-    throw error_c(Y("flac_reader: Could not read all header packets."));
+    throw mtx::input::header_parsing_x();
 
   try {
     uint32_t block_size = 0;
@@ -132,27 +125,22 @@ flac_reader_c::flac_reader_c(track_info_c &_ti)
     for (current_block = blocks.begin(); (current_block != blocks.end()) && (FLAC_BLOCK_TYPE_HEADERS == current_block->type); current_block++)
       block_size += current_block->len;
 
-    unsigned char *buf = (unsigned char *)safemalloc(block_size);
+    m_header = memory_c::alloc(block_size);
 
     block_size         = 0;
     for (current_block = blocks.begin(); (current_block != blocks.end()) && (FLAC_BLOCK_TYPE_HEADERS == current_block->type); current_block++) {
-      file->setFilePointer(current_block->filepos);
-      if (file->read(&buf[block_size], current_block->len) != current_block->len)
+      m_in->setFilePointer(current_block->filepos);
+      if (m_in->read(m_header->get_buffer() + block_size, current_block->len) != current_block->len)
         mxerror(Y("flac_reader: Could not read a header packet.\n"));
       block_size += current_block->len;
     }
 
-    header      = buf;
-    header_size = block_size;
-
-  } catch (error_c &error) {
+  } catch (mtx::exception &) {
     mxerror(Y("flac_reader: could not initialize the FLAC packetizer.\n"));
   }
 }
 
 flac_reader_c::~flac_reader_c() {
-  delete file;
-  safefree(header);
 }
 
 void
@@ -160,8 +148,8 @@ flac_reader_c::create_packetizer(int64_t) {
   if (!demuxing_requested('a', 0) || (NPTZR() != 0))
     return;
 
-  add_packetizer(new flac_packetizer_c(this, m_ti, header, header_size));
-  mxinfo_tid(m_ti.m_fname, 0, Y("Using the FLAC output module.\n"));
+  add_packetizer(new flac_packetizer_c(this, m_ti, m_header->get_buffer(), m_header->get_size()));
+  show_packetizer_info(0, PTZR0);
 }
 
 bool
@@ -173,7 +161,7 @@ flac_reader_c::parse_file() {
   int result, progress, old_progress;
   bool ok;
 
-  file->setFilePointer(0);
+  m_in->setFilePointer(0);
   metadata_parsed = false;
 
   mxinfo(Y("+-> Parsing the FLAC file. This can take a LONG time.\n"));
@@ -186,7 +174,7 @@ flac_reader_c::parse_file() {
                                        flac_metadata_cb, flac_error_cb, this) != FLAC__STREAM_DECODER_INIT_STATUS_OK)
     mxerror(Y("flac_reader: Could not initialize the FLAC decoder.\n"));
 
-  result = (int)FLAC__stream_decoder_process_until_end_of_metadata(decoder);
+  result = FLAC__stream_decoder_process_until_end_of_metadata(decoder);
 
   mxverb(2, boost::format("flac_reader: extract->metadata, result: %1%, mdp: %2%, num blocks: %3%\n") % result % metadata_parsed % blocks.size());
 
@@ -209,7 +197,7 @@ flac_reader_c::parse_file() {
   while (ok) {
     state = FLAC__stream_decoder_get_state(decoder);
 
-    progress = (int)(file->getFilePointer() * 100 / file_size);
+    progress = m_in->getFilePointer() * 100 / m_size;
     if ((progress - old_progress) >= 5) {
       mxinfo(boost::format(Y("+-> Pre-parsing FLAC file: %1%%%%2%")) % progress % "\r");
       old_progress = progress;
@@ -242,7 +230,7 @@ flac_reader_c::parse_file() {
   FLAC__stream_decoder_reset(decoder);
   FLAC__stream_decoder_delete(decoder);
 
-  file->setFilePointer(0);
+  m_in->setFilePointer(0);
   blocks[0].len     -= 4;
   blocks[0].filepos  = 4;
 
@@ -256,8 +244,8 @@ flac_reader_c::read(generic_packetizer_c *,
     return flush_packetizers();
 
   memory_cptr buf = memory_c::alloc(current_block->len);
-  file->setFilePointer(current_block->filepos);
-  if (file->read(buf, current_block->len) != current_block->len)
+  m_in->setFilePointer(current_block->filepos);
+  if (m_in->read(buf, current_block->len) != current_block->len)
     return flush_packetizers();
 
   unsigned int samples_here = flac_get_num_samples(buf->get_buffer(), current_block->len, stream_info);
@@ -276,7 +264,7 @@ flac_reader_c::read_cb(FLAC__byte buffer[],
   unsigned bytes_read, wanted_bytes;
 
   wanted_bytes = *bytes;
-  bytes_read   = file->read((unsigned char *)buffer, wanted_bytes);
+  bytes_read   = m_in->read(reinterpret_cast<unsigned char *>(buffer), wanted_bytes);
   *bytes       = bytes_read;
 
   return bytes_read == wanted_bytes ? FLAC__STREAM_DECODER_READ_STATUS_CONTINUE : FLAC__STREAM_DECODER_READ_STATUS_END_OF_STREAM;
@@ -318,66 +306,60 @@ flac_reader_c::metadata_cb(const FLAC__StreamMetadata *metadata) {
 
 void
 flac_reader_c::error_cb(FLAC__StreamDecoderErrorStatus status) {
-  mxerror(boost::format(Y("flac_reader: Error parsing the file: %1%\n")) % (int)status);
+  mxerror(boost::format(Y("flac_reader: Error parsing the file: %1%\n")) % static_cast<int>(status));
 }
 
 FLAC__StreamDecoderSeekStatus
 flac_reader_c::seek_cb(uint64_t new_pos) {
-  file->setFilePointer(new_pos, seek_beginning);
-  if (file->getFilePointer() == new_pos)
+  m_in->setFilePointer(new_pos, seek_beginning);
+  if (m_in->getFilePointer() == new_pos)
     return FLAC__STREAM_DECODER_SEEK_STATUS_OK;
   return FLAC__STREAM_DECODER_SEEK_STATUS_ERROR;
 }
 
 FLAC__StreamDecoderTellStatus
 flac_reader_c::tell_cb(uint64_t &absolute_byte_offset) {
-  absolute_byte_offset = file->getFilePointer();
+  absolute_byte_offset = m_in->getFilePointer();
   return FLAC__STREAM_DECODER_TELL_STATUS_OK;
 }
 
 FLAC__StreamDecoderLengthStatus
 flac_reader_c::length_cb(uint64_t &stream_length) {
-  stream_length = file_size;
+  stream_length = m_size;
   return FLAC__STREAM_DECODER_LENGTH_STATUS_OK;
 }
 
 FLAC__bool
 flac_reader_c::eof_cb() {
-  return file->getFilePointer() >= file_size;
-}
-
-int
-flac_reader_c::get_progress() {
-  return 100 * distance(blocks.begin(), current_block) / blocks.size();
+  return m_in->getFilePointer() >= m_size;
 }
 
 void
 flac_reader_c::identify() {
-  id_result_container("FLAC");
+  id_result_container();
   id_result_track(0, ID_RESULT_TRACK_AUDIO, "FLAC");
 }
 
 #else  // HAVE_FLAC_FORMAT_H
 
-int
+bool
 flac_reader_c::probe_file(mm_io_c *io,
                           uint64_t size) {
-  unsigned char data[4];
-
   if (4 > size)
-    return 0;
+    return false;
+
+  std::string data;
   try {
     io->setFilePointer(0, seek_beginning);
     if (io->read(data, 4) != 4)
-      return 0;
+      return false;
     io->setFilePointer(0, seek_beginning);
+
+    if (data == "fLaC")
+      id_result_container_unsupported(in->get_file_name(), "FLAC");
   } catch (...) {
-    return 0;
   }
-  if (strncmp((char *)data, "fLaC", 4))
-    return 0;
-  id_result_container_unsupported(io->get_file_name(), "FLAC");
-  return 1;
+  return false;
 }
 
 #endif // HAVE_FLAC_FORMAT_H
