@@ -21,22 +21,24 @@
 
 class ivf_reader_c: public generic_reader_c {
 private:
-  mm_file_io_cptr m_in;
-  uint64_t m_bytes_processed, m_size;
   uint16_t m_width, m_height;
   uint64_t m_frame_rate_num, m_frame_rate_den;
   int64_t m_previous_timestamp;
 
 public:
-  ivf_reader_c(track_info_c &p_ti);
+  ivf_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~ivf_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("IVF (VP8)") : "IVF (VP8)";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
-  virtual int get_progress();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static int probe_file(mm_io_c *in, uint64_t size);
 };
 
 #endif // __R_IVF_H
