@@ -19,6 +19,7 @@
 
 #include <algorithm>
 #include <boost/math/common_factor.hpp>
+#include <boost/range/algorithm.hpp>
 #include <cstring>
 #include <zlib.h>
 
@@ -45,6 +46,8 @@
 
 using namespace libmatroska;
 
+#define MAX_INTERLEAVING_BADNESS 0.4
+
 #if defined(ARCH_BIGENDIAN)
 #define BE2STR(a) ((char *)&a)[0] % ((char *)&a)[1] % ((char *)&a)[2] % ((char *)&a)[3]
 #define LE2STR(a) ((char *)&a)[3] % ((char *)&a)[2] % ((char *)&a)[1] % ((char *)&a)[0]
@@ -107,9 +110,10 @@ qtmp4_reader_c::qtmp4_reader_c(const track_info_c &ti,
   , m_time_scale(1)
   , m_compression_algorithm(0)
   , m_main_dmx(-1)
-  , m_debug_chapters(debugging_requested("qtmp4") || debugging_requested("qtmp4_full") || debugging_requested("qtmp4_chapters"))
-  , m_debug_headers( debugging_requested("qtmp4") || debugging_requested("qtmp4_full") || debugging_requested("qtmp4_headers"))
-  , m_debug_tables(                                  debugging_requested("qtmp4_full") || debugging_requested("qtmp4_tables"))
+  , m_debug_chapters(    debugging_requested("qtmp4") || debugging_requested("qtmp4_full") || debugging_requested("qtmp4_chapters"))
+  , m_debug_headers(     debugging_requested("qtmp4") || debugging_requested("qtmp4_full") || debugging_requested("qtmp4_headers"))
+  , m_debug_tables(                                      debugging_requested("qtmp4_full") || debugging_requested("qtmp4_tables"))
+  , m_debug_interleaving(debugging_requested("qtmp4") || debugging_requested("qtmp4_full") || debugging_requested("qtmp4_interleaving"))
 {
 }
 
@@ -302,6 +306,8 @@ qtmp4_reader_c::parse_headers() {
     dmx->ok = true;
   }
 
+  detect_interleaving();
+
   read_chapter_track();
 
   if (!g_identifying)
@@ -692,6 +698,7 @@ qtmp4_reader_c::handle_moov_atom(qt_atom_t parent,
 
     else if (FOURCC('t', 'r', 'a', 'k') == atom.fourcc) {
       qtmp4_demuxer_cptr new_dmx(new qtmp4_demuxer_c);
+      new_dmx->id = m_demuxers.size();
 
       handle_trak_atom(new_dmx, atom.to_parent(), level + 1);
       if (('?' != new_dmx->type) && (0 != get_uint32_le(new_dmx->fourcc)))
@@ -1196,7 +1203,7 @@ qtmp4_reader_c::handle_elst_atom(qtmp4_demuxer_cptr &new_dmx,
 }
 
 void
-qtmp4_reader_c::handle_tkhd_atom(qtmp4_demuxer_cptr &new_dmx,
+qtmp4_reader_c::handle_tkhd_atom(qtmp4_demuxer_cptr &/* new_dmx */,
                                  qt_atom_t atom,
                                  int level) {
   tkhd_atom_t tkhd;
@@ -1208,8 +1215,6 @@ qtmp4_reader_c::handle_tkhd_atom(qtmp4_demuxer_cptr &new_dmx,
     throw mtx::input::header_parsing_x();
 
   mxdebug_if(m_debug_headers, boost::format("%1%Track ID: %2%\n") % space(level * 2 + 1) % get_uint32_be(&tkhd.track_id));
-
-  new_dmx->id = get_uint32_be(&tkhd.track_id);
 }
 
 void
@@ -1688,6 +1693,36 @@ qtmp4_reader_c::recode_chapter_entries(std::vector<qtmp4_chapter_entry_t> &entri
   converter->enable_byte_order_marker_detection(false);
 }
 
+void
+qtmp4_reader_c::detect_interleaving() {
+  std::list<qtmp4_demuxer_cptr> demuxers_to_read;
+  boost::remove_copy_if(m_demuxers, std::back_inserter(demuxers_to_read), [&](const qtmp4_demuxer_cptr &dmx) {
+      return !(dmx->ok && (dmx->is_audio() || dmx->is_video()) && demuxing_requested(dmx->type, dmx->id) && (dmx->sample_table.size() > 1));
+    });
+
+  if (demuxers_to_read.size() < 2) {
+    mxdebug_if(m_debug_interleaving, boost::format("Interleaving: Not enough tracks to care about interleaving.\n"));
+    return;
+  }
+
+  auto cmp = [](const qt_sample_t &s1, const qt_sample_t &s2) -> uint64_t { return s1.pos < s2.pos; };
+
+  std::list<float> gradients;
+  for (auto &dmx : demuxers_to_read) {
+    uint64_t min = boost::min_element(dmx->sample_table, cmp)->pos;
+    uint64_t max = boost::max_element(dmx->sample_table, cmp)->pos;
+    gradients.push_back(static_cast<float>(max - min) / m_in->get_size());
+
+    mxdebug_if(m_debug_interleaving, boost::format("Interleaving: Track id %1% min %2% max %3% gradient %4%\n") % dmx->id % min % max % gradients.back());
+  }
+
+  float badness = *boost::max_element(gradients) - *boost::min_element(gradients);
+  mxdebug_if(m_debug_interleaving, boost::format("Interleaving: Badness: %1% (%2%)\n") % badness % (MAX_INTERLEAVING_BADNESS < badness ? "badly interleaved" : "ok"));
+
+  if (MAX_INTERLEAVING_BADNESS < badness)
+    m_in->enable_buffering(false);
+}
+
 // ----------------------------------------------------------------------
 
 void
@@ -2072,3 +2107,15 @@ qtmp4_demuxer_c::read_first_bytes(memory_cptr &buf,
 
   return 0 == num_bytes;
 }
+
+bool
+qtmp4_demuxer_c::is_audio()
+  const {
+  return 'a' == type;
+}
+
+bool
+qtmp4_demuxer_c::is_video()
+  const {
+  return 'v' == type;
+}
