@@ -672,8 +672,5 @@ vobsub_reader_c::flush_packetizers() {
 
 void
 vobsub_reader_c::add_available_track_ids() {
-  size_t i;
-
-  for (i = 0; i < tracks.size(); i++)
-    add_available_track_id(i);
+  add_available_track_id_range(tracks.size());
 }
