@@ -25,21 +25,24 @@
 
 class wavpack_reader_c: public generic_reader_c {
 private:
-  mm_io_c *io,*io_correc;
-  int64_t size;
+  mm_io_cptr m_in_correc;
   wavpack_header_t header, header_correc;
   wavpack_meta_t meta, meta_correc;
 
 public:
-  wavpack_reader_c(track_info_c &_ti) throw (error_c);
+  wavpack_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~wavpack_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("WAVPACK") : "WAVPACK";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
-  virtual int get_progress();
   virtual void identify();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static int probe_file(mm_io_c *in, uint64_t size);
 };
 
 #endif // __R_WAVPACK_H
