@@ -49,7 +49,6 @@
 #include "common/extern_data.h"
 #include "common/file_types.h"
 #include "common/fs_sys_helpers.h"
-#include "common/hacks.h"
 #include "common/iso639.h"
 #include "common/mm_io.h"
 #include "common/segmentinfo.h"
@@ -1709,12 +1708,6 @@ parse_args(std::vector<std::string> args) {
       g_outfile = next_arg;
       sit++;
 
-    } else if (this_arg == "--engage") {
-      if (no_next_arg)
-        mxerror(Y("'--engage' lacks its argument.\n"));
-      engage_hacks(next_arg);
-      sit++;
-
     } else if ((this_arg == "-w") || (this_arg == "--webm"))
       set_output_compatibility(OC_WEBM);
   }
