@@ -68,9 +68,8 @@
 #include "common/fs_sys_helpers.h"
 #include "common/hacks.h"
 #include "common/math.h"
-#include "common/mm_io.h"
-#include "common/mm_read_cache_io.h"
-#include "common/mm_write_cache_io.h"
+#include "common/mm_read_buffer_io.h"
+#include "common/mm_write_buffer_io.h"
 #include "common/strings/formatting.h"
 #include "common/tags/tags.h"
 #include "common/translation.h"
@@ -319,15 +318,16 @@ file_names_to_paths(const std::vector<std::string> &file_names) {
 }
 
 static mm_io_cptr
-open_input_file(filelist_t &file,
-                bool use_probe_cache) {
+open_input_file(filelist_t &file) {
   try {
     if (file.all_names.size() == 1)
-      return use_probe_cache ? mm_io_cptr(mm_probe_cache_io_c::open(file.name, 20 * 1024 * 1024)) : mm_file_io_c::open(file.name);
+      return mm_io_cptr(new mm_read_buffer_io_c(new mm_file_io_c(file.name), 1 << 17));
+
     else {
       std::vector<bfs::path> paths = file_names_to_paths(file.all_names);
-      return use_probe_cache ?  mm_io_cptr(new mm_probe_cache_io_c(new mm_multi_file_io_c(paths, file.name), 20 * 1024 * 1024)) : mm_io_cptr(new mm_multi_file_io_c(paths, file.name));
+      return mm_io_cptr(new mm_read_buffer_io_c(new mm_multi_file_io_c(paths, file.name), 1 << 17));
     }
+
   } catch (...) {
     mxerror(boost::format(Y("The source file '%1%' could not be opened successfully, or retrieving its size by seeking to the end did not work.\n")) % file.name);
     return mm_io_cptr(NULL);
@@ -341,9 +341,9 @@ open_input_file(filelist_t &file,
 */
 void
 get_file_type(filelist_t &file) {
-  mm_io_cptr af_io = open_input_file(file, true);
+  mm_io_cptr af_io = open_input_file(file);
   mm_io_c *io      = af_io.get_object();
-  int64_t size     = io->get_size();
+  int64_t size     = std::min(io->get_size(), static_cast<int64_t>(1 << 25));
 
   file_type_e type = FILE_TYPE_IS_UNKNOWN;
   // File types that can be detected unambiguously but are not supported
@@ -1117,7 +1117,7 @@ void
 create_readers() {
   for (auto &file : g_files) {
     try {
-      mm_io_cptr input_file = open_input_file(file, false);
+      mm_io_cptr input_file = open_input_file(file);
 
       switch (file.type) {
         case FILE_TYPE_AAC:
@@ -1429,7 +1429,7 @@ create_next_output_file() {
 
   // Open the output file.
   try {
-    s_out = mm_write_cache_io_c::open(this_outfile, 20 * 1024 * 1024);
+    s_out = mm_write_buffer_io_c::open(this_outfile, 20 * 1024 * 1024);
   } catch (...) {
     mxerror(boost::format(Y("The output file '%1%' could not be opened for writing (%2%).\n")) % this_outfile % strerror(errno));
   }
