@@ -32,21 +32,20 @@ private:
   int64_t m_single_packet_duration;
 
 public:
-  aac_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int id, int profile, int samples_per_sec, int channels,
-                   bool emphasis_present, bool _headerless = false) throw (error_c);
+  aac_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int id, int profile, int samples_per_sec, int channels, bool emphasis_present, bool _headerless = false);
   virtual ~aac_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "AAC";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("AAC") : "AAC";
   }
 
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 private:
-  virtual unsigned char *get_aac_packet(unsigned long *header, aac_header_t *aacheader);
+  virtual unsigned char *get_aac_packet(aac_header_t *aacheader);
   virtual int process_headerless(packet_cptr packet);
 };
 
