@@ -27,7 +27,6 @@ ra_packetizer_c::ra_packetizer_c(generic_reader_c *p_reader,
                                  uint32_t fourcc,
                                  unsigned char *private_data,
                                  int private_size)
-  throw (error_c)
   : generic_packetizer_c(p_reader, p_ti)
   , m_samples_per_sec(samples_per_sec)
   , m_channels(channels)
@@ -45,7 +44,7 @@ void
 ra_packetizer_c::set_headers() {
   std::string codec_id = (boost::format("A_REAL/%1%%2%%3%%4%")
                           % (char)(m_fourcc >> 24) % (char)((m_fourcc >> 16) & 0xff) % (char)((m_fourcc >> 8) & 0xff) % (char)(m_fourcc & 0xff)).str();
-  set_codec_id(upcase(codec_id));
+  set_codec_id(ba::to_upper_copy(codec_id));
   set_audio_sampling_freq((float)m_samples_per_sec);
   set_audio_channels(m_channels);
   set_audio_bit_depth(m_bits_per_sample);
