@@ -1,11 +1,22 @@
-#include "os.h"
+/*
+   vc1parser - A tool for testing the VC1 bitstream parser
 
-#include "bit_cursor.h"
-#include "byte_buffer.h"
-#include "checksums.h"
-#include "common.h"
-#include "mm_io.h"
-#include "vc1_common.h"
+   Distributed under the GPL
+   see the file COPYING for details
+   or visit http://www.gnu.org/copyleft/gpl.html
+
+   Written by Moritz Bunkus <moritz@bunkus.org>.
+*/
+
+#include "common/os.h"
+
+#include "common/bit_cursor.h"
+#include "common/byte_buffer.h"
+#include "common/checksums.h"
+#include "common/common_pch.h"
+#include "common/mm_io.h"
+#include "common/translation.h"
+#include "common/vc1.h"
 
 static bool g_opt_checksum         = false;
 static bool g_opt_entrypoints      = false;
@@ -34,18 +45,18 @@ protected:
   virtual void dump_entrypoint(vc1::entrypoint_t &entrypoint);
   virtual void dump_frame_header(vc1::frame_header_t &frame_header);
 
-  virtual string create_checksum_info(memory_cptr packet);
+  virtual std::string create_checksum_info(memory_cptr packet);
 };
 
 void
 vc1_info_c::handle_end_of_sequence_packet(memory_cptr packet) {
-  string checksum = create_checksum_info(packet);
+  std::string checksum = create_checksum_info(packet);
   mxinfo(boost::format(Y("End of sequence at %1% size %2%%3%\n")) % m_stream_pos % packet->get_size() % checksum);
 }
 
 void
 vc1_info_c::handle_entrypoint_packet(memory_cptr packet) {
-  string checksum = create_checksum_info(packet);
+  std::string checksum = create_checksum_info(packet);
   mxinfo(boost::format(Y("Entrypoint at %1% size %2%%3%\n")) % m_stream_pos % packet->get_size() % checksum);
 
   if (!g_opt_entrypoints)
@@ -57,19 +68,19 @@ vc1_info_c::handle_entrypoint_packet(memory_cptr packet) {
   }
 
   vc1::entrypoint_t entrypoint;
-  if (vc1::parse_entrypoint(packet->get(), packet->get_size(), entrypoint, m_seqhdr))
+  if (vc1::parse_entrypoint(packet->get_buffer(), packet->get_size(), entrypoint, m_seqhdr))
     dump_entrypoint(entrypoint);
 }
 
 void
 vc1_info_c::handle_field_packet(memory_cptr packet) {
-  string checksum = create_checksum_info(packet);
+  std::string checksum = create_checksum_info(packet);
   mxinfo(boost::format(Y("Field at %1% size %2%%3%\n")) % m_stream_pos % packet->get_size() % checksum);
 }
 
 void
 vc1_info_c::handle_frame_packet(memory_cptr packet) {
-  string checksum = create_checksum_info(packet);
+  std::string checksum = create_checksum_info(packet);
   mxinfo(boost::format(Y("Frame at %1% size %2%%3%\n")) % m_stream_pos % packet->get_size() % checksum);
 
   if (!g_opt_frames)
@@ -81,16 +92,16 @@ vc1_info_c::handle_frame_packet(memory_cptr packet) {
   }
 
   vc1::frame_header_t frame_header;
-  if (vc1::parse_frame_header(packet->get(), packet->get_size(), frame_header, m_seqhdr))
+  if (vc1::parse_frame_header(packet->get_buffer(), packet->get_size(), frame_header, m_seqhdr))
     dump_frame_header(frame_header);
 }
 
 void
 vc1_info_c::handle_sequence_header_packet(memory_cptr packet) {
-  string checksum = create_checksum_info(packet);
+  std::string checksum = create_checksum_info(packet);
   mxinfo(boost::format(Y("Sequence header at %1% size %2%%3%\n")) % m_stream_pos % packet->get_size() % checksum);
 
-  m_seqhdr_found = vc1::parse_sequence_header(packet->get(), packet->get_size(), m_seqhdr);
+  m_seqhdr_found = vc1::parse_sequence_header(packet->get_buffer(), packet->get_size(), m_seqhdr);
 
   if (g_opt_sequence_headers) {
     if (m_seqhdr_found)
@@ -102,23 +113,23 @@ vc1_info_c::handle_sequence_header_packet(memory_cptr packet) {
 
 void
 vc1_info_c::handle_slice_packet(memory_cptr packet) {
-  string checksum = create_checksum_info(packet);
+  std::string checksum = create_checksum_info(packet);
   mxinfo(boost::format(Y("Slice at %1% size %2%%3%\n")) % m_stream_pos % packet->get_size() % checksum);
 }
 
 void
 vc1_info_c::handle_unknown_packet(uint32_t marker,
                                   memory_cptr packet) {
-  string checksum = create_checksum_info(packet);
+  std::string checksum = create_checksum_info(packet);
   mxinfo(boost::format(Y("Unknown (0x%|1$08x|) at %2% size %3%%4%\n")) % marker % m_stream_pos % packet->get_size() % checksum);
 }
 
-string
+std::string
 vc1_info_c::create_checksum_info(memory_cptr packet) {
   if (!g_opt_checksum)
     return "";
 
-  return (boost::format(Y(" checksum 0x%|1$08x|")) % calc_adler32(packet->get(), packet->get_size())).str();
+  return (boost::format(Y(" checksum 0x%|1$08x|")) % calc_adler32(packet->get_buffer(), packet->get_size())).str();
 }
 
 void
@@ -269,21 +280,11 @@ show_version() {
   mxexit(0);
 }
 
-static void
-setup() {
-  init_stdio();
-  init_locales();
+static std::string
+parse_args(std::vector<std::string> &args) {
+  std::string file_name;
 
-  mm_file_io_c::setup();
-  cc_local_utf8 = utf8_init("");
-  init_cc_stdio();
-}
-
-static string
-parse_args(vector<string> &args) {
-  string file_name;
-
-  vector<string>::iterator arg = args.begin();
+  std::vector<std::string>::iterator arg = args.begin();
   while (arg != args.end()) {
     if ((*arg == "-h") || (*arg == "--help"))
       show_help();
@@ -319,7 +320,7 @@ parse_args(vector<string> &args) {
 }
 
 static void
-parse_file(const string &file_name) {
+parse_file(const std::string &file_name) {
   mm_file_io_c in(file_name);
 
   const int buf_size = 100000;
@@ -329,7 +330,7 @@ parse_file(const string &file_name) {
     mxerror(Y("File too small\n"));
 
   memory_cptr mem    = memory_c::alloc(buf_size);
-  unsigned char *ptr = mem->get();
+  unsigned char *ptr = mem->get_buffer();
 
   vc1_info_c parser;
 
@@ -347,10 +348,10 @@ parse_file(const string &file_name) {
 int
 main(int argc,
      char **argv) {
-  setup();
+  mtx_common_init();
 
-  vector<string> args = command_line_utf8(argc, argv);
-  string file_name    = parse_args(args);
+  std::vector<std::string> args = command_line_utf8(argc, argv);
+  std::string file_name    = parse_args(args);
 
   try {
     parse_file(file_name);
