@@ -38,7 +38,13 @@ class TestController
   end
 
   def get_num_processors
-    IO.readlines("/proc/cpuinfo").collect { |line| /^processor\s+:\s+(\d+)/.match(line) ? $1.to_i : 0 }.max + 1
+    case RUBY_PLATFORM
+    when /darwin/
+      np = `/usr/sbin/sysctl -n hw.availcpu`.to_i
+    else
+      np = IO.readlines("/proc/cpuinfo").collect { |line| /^processor\s+:\s+(\d+)/.match(line) ? $1.to_i : 0 }.max + 1
+    end
+    return np > 0 ? np : 1
   end
 
   def num_threads=(num)
@@ -197,6 +203,20 @@ class Test
     @tmp_num_mutex  = Mutex.new
     @commands       = Array.new
     @debug_commands = Array.new
+
+    # install md5 handler
+    case RUBY_PLATFORM
+      when /darwin/
+        @md5 = lambda do |name|
+          @debug_commands << "/sbin/md5 #{name}"
+          `/sbin/md5 #{name}`.chomp.gsub(/.*=\s*/, "")
+        end
+      else
+        @md5 = lambda do |name|
+          @debug_commands << "md5sum #{name}"
+          `md5sum #{name}`.chomp.gsub(/\s+.*/, "")
+      end
+    end
   end
 
   def description
@@ -259,8 +279,7 @@ class Test
   end
 
   def hash_file(name)
-    @debug_commands << "md5sum #{name}"
-    `md5sum #{name}`.chomp.gsub(/\s+.*/, "")
+    @md5.call name
   end
 
   def hash_tmp(erase = true)
@@ -285,14 +304,22 @@ class Test
     sys command, retcode
   end
 
+  def propedit *args
+    retcode = args.detect { |a| !a.is_a? String } || 0
+    args.reject!          { |a| !a.is_a? String }
+
+    command = "../src/mkvpropedit --engage no_variable_data " + (args.size == 1 ? tmp : args.shift) + " " + args.shift
+    sys command, retcode
+  end
+
   def xtr_tracks_s(*args)
-    command = "../src/mkvextract tracks data/mkv/complex.mkv --no-variable-data " + args.join(" ") + ":#{tmp}"
+    command = "../src/mkvextract tracks data/mkv/complex.mkv --engage no_variable_data " + args.join(" ") + ":#{tmp}"
     sys command, 0
     hash_tmp
   end
 
   def xtr_tracks(*args)
-    command = "../src/mkvextract tracks #{args.shift} --no-variable-data " + args.join(" ")
+    command = "../src/mkvextract tracks #{args.shift} --engage no_variable_data " + args.join(" ")
     sys command, 0
   end
 end
@@ -381,7 +408,7 @@ class Results
 end
 
 def main
-  ENV['LC_ALL'] = "en_US.UTF-8"
+  ENV[ /darwin/i.match(RUBY_PLATFORM) ? 'LANG' : 'LC_ALL' ] = 'en_US.UTF-8'
   ENV['PATH']   = "../src:" + ENV['PATH']
 
   controller = TestController.new
